import React from 'react';
import { useRouter } from 'next/navigation';
import { useLanguage } from '@/contexts/language-context';
import { ShoppingBasket, Smartphone, ShieldCheck } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Card } from '@/components/ui/card';

export default function LandingPage() {
    const router = useRouter();
    const { t } = useLanguage();

    return (
        <div className="bg-gradient-to-b from-background to-secondary min-h-[calc(100vh-4rem)]">
            {/* Hero Section */}
            <section className="container mx-auto pt-10 md:pt-20 pb-16 px-4">
                <div className="grid grid-cols-1 md:grid-cols-2 gap-8 items-center">
                    <div className="flex flex-col space-y-6">
                        <h1 className="text-4xl md:text-5xl lg:text-6xl font-extrabold tracking-tight">
                            {t('appName')}
                            <span className="text-primary">.</span>
                        </h1>
                        <p className="text-xl text-muted-foreground">
                            {t('landingTagline')}
                        </p>
                        <div className="flex flex-col sm:flex-row gap-4">
                            <Button
                                size="lg"
                                className="bg-primary hover:bg-primary/90 text-primary-foreground"
                                onClick={() => router.push('/auth')}
                            >
                                {t('getStarted')}
                            </Button>
                            <Button
                                variant="outline"
                                size="lg"
                                onClick={() => router.push('/auth?tab=signin')}
                            >
                                {t('login')}
                            </Button>
                        </div>
                    </div>
                    <div className="hidden md:flex justify-center">
                        <div className="relative w-[350px] h-[400px] bg-card rounded-lg shadow-xl border overflow-hidden">
                            <div className="absolute top-0 left-0 right-0 h-14 bg-card border-b flex items-center px-4">
                                <ShoppingBasket className="h-5 w-5 text-primary mr-2" />
                                <span className="font-medium">{t('appName')}</span>
                            </div>
                            <div className="pt-16 px-4 pb-4">
                                <div className="bg-accent/30 rounded-md p-3 mb-3">
                                    <p className="font-medium">Supermarket</p>
                                </div>
                                <ul className="space-y-2">
                                    {['Milk', 'Eggs', 'Bread', 'Apples'].map((item, i) => (
                                        <li key={i} className="flex items-center p-2 bg-background rounded-md">
                                            <div className="h-4 w-4 rounded-sm border mr-2 flex-shrink-0" />
                                            <span>{item}</span>
                                        </li>
                                    ))}
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </section>

            {/* Features Section */}
            <section className="bg-card py-16">
                <div className="container mx-auto px-4">
                    <h2 className="text-3xl font-bold text-center mb-12">{t('featuresTitle')}</h2>
                    <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
                        <FeatureCard
                            icon={<ShoppingBasket className="h-10 w-10 text-primary" />}
                            title={t('feature1Title')}
                            description={t('feature1Desc')}
                        />
                        <FeatureCard
                            icon={<Smartphone className="h-10 w-10 text-primary" />}
                            title={t('feature2Title')}
                            description={t('feature2Desc')}
                        />
                        <FeatureCard
                            icon={<ShieldCheck className="h-10 w-10 text-primary" />}
                            title={t('feature3Title')}
                            description={t('feature3Desc')}
                        />
                    </div>
                </div>
            </section>

            {/* How it works section */}
            <section className="py-16">
                <div className="container mx-auto px-4">
                    <h2 className="text-3xl font-bold text-center mb-12">{t('howItWorksTitle')}</h2>
                    <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
                        <StepCard
                            number="1"
                            title={t('step1Title')}
                            description={t('step1Desc')}
                        />
                        <StepCard
                            number="2"
                            title={t('step2Title')}
                            description={t('step2Desc')}
                        />
                        <StepCard
                            number="3"
                            title={t('step3Title')}
                            description={t('step3Desc')}
                        />
                    </div>
                </div>
            </section>

            {/* CTA Section */}
            <section className="bg-primary/10 py-16">
                <div className="container mx-auto px-4 text-center">
                    <h2 className="text-3xl font-bold mb-6">{t('ctaTitle')}</h2>
                    <p className="text-xl text-muted-foreground max-w-2xl mx-auto mb-8">
                        {t('ctaDesc')}
                    </p>
                    <Button
                        size="lg"
                        className="bg-primary hover:bg-primary/90 text-primary-foreground"
                        onClick={() => router.push('/auth')}
                    >
                        {t('getStartedFree')}
                    </Button>
                </div>
            </section>

            {/* Footer */}
            <footer className="bg-card py-8 border-t">
                <div className="container mx-auto px-4">
                    <div className="flex flex-col md:flex-row justify-between items-center">
                        <div className="flex items-center mb-4 md:mb-0">
                            <ShoppingBasket className="h-6 w-6 text-primary mr-2" />
                            <span className="font-bold">{t('appName')}</span>
                        </div>
                        <p className="text-sm text-muted-foreground">
                            © {new Date().getFullYear()} {t('appName')}. {t('copyright')}
                        </p>
                    </div>
                </div>
            </footer>
        </div>
    );
}

// Component for feature cards
function FeatureCard({ icon, title, description }: { icon: React.ReactNode, title: string, description: string }) {
    return (
        <Card className="flex flex-col items-center text-center p-6">
            <div className="mb-4">{icon}</div>
            <h3 className="text-xl font-semibold mb-2">{title}</h3>
            <p className="text-muted-foreground">{description}</p>
        </Card>
    );
}

// Component for step cards
function StepCard({ number, title, description }: { number: string, title: string, description: string }) {
    return (
        <div className="flex flex-col items-center text-center">
            <div className="h-12 w-12 rounded-full bg-primary text-primary-foreground flex items-center justify-center text-xl font-bold mb-4">
                {number}
            </div>
            <h3 className="text-xl font-semibold mb-2">{title}</h3>
            <p className="text-muted-foreground">{description}</p>
        </div>
    );
} 